GeneratorOptions class
Constructors
- GeneratorOptions({String defaultLocale = 'en', String className = 'IntlKeys', bool format = true, bool mangle = false, bool builtin = false, bool debug = false, bool pruneUnused = false, bool promoteLater = false, bool dryRun = true, String source = 'assets/intl', String output = 'lib/intl.dart'})
-
const
Properties
- builtin → bool
-
Include the translations into the output dart source
final
- className → String
-
The class name to generate
final
- debug → bool
-
Generate debug strings
final
- defaultLocale → String
-
The default locale
final
- dryRun → bool
-
When true, do not write modified JSON/Dart files to disk
final
- format → bool
-
Format the generated dart file
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mangle → bool
-
Change keys to a random string
final
- output → String
-
Output filename
final
- promoteLater → bool
-
Promote JsonIntl.later() strings to translation keys before generating
final
- pruneUnused → bool
-
Remove unused translation keys from JSON files before generating
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
Source directory
final
Methods
-
copyWith(
{String? defaultLocale, String? className, bool? format, bool? mangle, bool? builtin, bool? debug, bool? pruneUnused, bool? promoteLater, bool? dryRun, String? source, String? output}) → GeneratorOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- builder → const GeneratorOptions
- def → const GeneratorOptions